@@ -1,7 +1,8 @@
 from requests import Session
 import json
 import urllib3
-
+from py_viptela import HttpMethods
+from py_viptela.query_builder import Builder
 class Vmanage(object):
     
     def __init__(self, host, port, username, password):
@@ -29,4 +30,6 @@ class Vmanage(object):
         # configure headers for further use
         self.session.headers['Content-Type'] = 'application/json'
         self.session.headers['X-XSRF-TOKEN'] = token
-        
\ No newline at end of file
+        
+        self.client = HttpMethods.HttpClient(self.session)
+        self.builder = Builder()
\ No newline at end of file
